@@ -1,42 +1,41 @@
 # -*- coding: utf-8 -*-
 
-import os, sys, argparse
+import os
+import argparse
 from datetime import date
-from flaskup import app, utils
+from flaskup.models import SharedFile
+from flaskup.filters import filesizeformat
+
 
 def action_clean(quiet):
     today = date.today()
-    upload_folder = app.config['FLASKUP_UPLOAD_FOLDER']
     count = 0
     deleted_files = []
-    for root, dirs, files in os.walk(upload_folder):
-        if utils.JSON_FILENAME in files:
-            try:
-                path, key = os.path.split(root)
-                infos = utils.get_file_info(key)
-                expire_date = infos['expire_date']
-                if expire_date < today:
-                    utils.remove_file(infos['key'])
-                    count += 1
-                    deleted_files.append(infos)
-            except Exception as e:
-                print >> sys.stderr, u"Error for '{0}': {1}".format(root, e)
+
+    for f in SharedFile.find_all():
+        if f.expire_date < today:
+            f.delete(notify=False)
+            count += 1
+            deleted_files.append(f)
 
     if not quiet and count > 0:
         print u'Files deleted: {0}'.format(count)
         for info in deleted_files:
-            print u" - '{0}'".format(os.path.join(info['path'], info['filename']))
+            print u" - '{0}' - {1}".format(os.path.join(info.path, info.filename),
+                                           filesizeformat(info.size, True))
+
 
 def list_actions():
     from flaskup import console
     attributes = dir(console)
-    
+
     actions = []
     for attribute in attributes:
         if attribute.startswith('action_'):
             actions.append(attribute[7:])
     return actions
 
+
 def main():
     # parse arguments
     parser = argparse.ArgumentParser(description='Flaskup! command line tool.')
